Documentation
¶
Overview ¶
Package opencode is the OpenCode client. Unlike the other clients, OpenCode has a single abstract routing flavor: the real protocol (OpenAI Responses, OpenAI Chat, Anthropic Messages, Bedrock, Vertex, Gemini) is decided at launch time from the chosen provider's compatibility map. The Menu flow goes straight from provider selection to launch; model selection happens inside OpenCode itself.
Index ¶
- type Client
- func (c *Client) BinaryName() string
- func (c *Client) CommonPaths() []string
- func (c *Client) Install(_ *config.Global) clients.InstallPlan
- func (c *Client) IsInstalled() bool
- func (c *Client) Menu(g *config.Global) menu.MenuItem
- func (c *Client) Name() string
- func (c *Client) QuickSelectLabel(g *config.Global) string
- func (c *Client) Replay(g *config.Global) tea.Cmd
- func (c *Client) Uninstall() clients.UninstallPlan
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct{}
Client is the OpenCode client.
func (*Client) BinaryName ¶
BinaryName implements clients.Client.
func (*Client) CommonPaths ¶
CommonPaths implements clients.Client.
func (*Client) Install ¶
func (c *Client) Install(_ *config.Global) clients.InstallPlan
Install implements clients.Client.
func (*Client) IsInstalled ¶
IsInstalled implements clients.Client.
func (*Client) QuickSelectLabel ¶
QuickSelectLabel implements clients.Client.
func (*Client) Uninstall ¶
func (c *Client) Uninstall() clients.UninstallPlan
Uninstall implements clients.Client.